@@ -33,7 +33,6 @@ Q_EXPORT_PLUGIN2(mbqt_qrplugin, WifiPlugin)
 
 WifiSink::WifiSink(const PluginInterface *interface) : PluginAction(interface)
 {
-    ready = false;
 }
 
 QString WifiSink::getText()
@@ -53,23 +52,17 @@ void WifiSink::clickAction(QWidget * parentWindow)
 
 void WifiSink::barcodeAnalysed(QString barcodeType, QString barcodeData)
 {
-    ready = false;
     if (barcodeType == "QR-Code" || barcodeType == "dmtx")
     {
         if (barcodeData.startsWith("WIFI:"))
         {
             QString wifiString = barcodeData.mid(5);
             if (parseWifiString(wifiString, wifiInfo))
-                ready = true;
+                emit isReady();
         }
     }
 }
 
-bool WifiSink::isReady()
-{
-    return ready;
-}
-
 bool WifiSink::extractPiece(QStringList& pieces, QString key, QString& value)
 {
     for (int i = 0; i < pieces.size(); i++)
